@@ -52,7 +52,6 @@
 #include <QMenu>
 #include <QPair>
 #include <QPushButton>
-#include <QSignalMapper>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
 
@@ -346,15 +345,12 @@ NewGameDlg::NewGameDlg( QWidget *parent, Game *game)
     m_selectablePlayer.push_back(new AiBecaiGui());
 
     m_playerTypeChooser = new QMenu(this);
-    QSignalMapper *menuMapper = new QSignalMapper(this);
     for (int i = 0 ; i < m_selectablePlayer.size() ; i++)
     {
         PlayerGui *selectablePlayer = m_selectablePlayer[i];
         QAction *action = m_playerTypeChooser->addAction(selectablePlayer->guiName());
-        menuMapper->setMapping(action, i);
-        connect(action, &QAction::triggered, menuMapper, static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
+        connect(action, &QAction::triggered, this, [this, i]() { slotAddPlayer(i);});
     }
-    connect(menuMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, &NewGameDlg::slotAddPlayer);
 
     m_w = new NewGameDlgUI(this);
     m_w->map->setMap(m_game->map());
@@ -440,8 +436,8 @@ NewGameDlg::init()
     playersListModel *model = static_cast<playersListModel*>(m_w->playerList->model());
     for(int i = 0; i < nrOfPlayers; ++i)
     {
-        QString keyName = QString("Player_%1").arg(i);
-        QString keyType = QString("PlayerType_%1").arg(i);
+        QString keyName = QStringLiteral("Player_%1").arg(i);
+        QString keyType = QStringLiteral("PlayerType_%1").arg(i);
 
         QString playerName = config.readEntry(keyName,QString());
         QString playerType = config.readEntry(keyType,QString());
@@ -595,9 +591,9 @@ NewGameDlg::save()
     config.writeEntry("NrOfPlayers", model->rowCount());
     for (int i = 0; i < model->rowCount(); ++i)
     {
-        QString  keyName        = QString("Player_%1").arg(i);
+        QString  keyName        = QStringLiteral("Player_%1").arg(i);
         QString  playerName = model->data(model->index(i, 0), Qt::DisplayRole).toString();
-        QString  keyType = QString("PlayerType_%1").arg(i);
+        QString  keyType = QStringLiteral("PlayerType_%1").arg(i);
         QString  playerType = model->data(model->index(i, 1), Qt::DisplayRole).toString();
 
         config.writeEntry(keyName, playerName);
